@@ -73,6 +73,35 @@ class DscAPI:
         except KeyError:
             return {}
 
+    def get_transactions_address(self, address: str, limit: int = 10, offset: int = 0) -> Dict[str, str]:
+        self.__validate_address(address)
+        resp = json.loads(self.__request_gate(f'address/{address}/txs?limit={limit}&offset={offset}'))
+        try:
+            return resp["result"]
+        except KeyError:
+            return {}
+
+    def get_coin_price(self, symbol: str) -> Dict[str, str]:
+        resp = json.loads(self.__request_gate(f'coin/{symbol}'))
+        try:
+            return resp["result"]['priceBase']
+        except KeyError:
+            return {}
+
+    def get_coin_by_symbol(self, symbol: str) -> Dict[str, str]:
+        resp = json.loads(self.__request_gate(f'coin/{symbol}'))
+        try:
+            return resp["result"]['priceBase']
+        except KeyError:
+            return {}
+
+    def get_coins(self, order: str = 'symbol', type_order: str = 'DESC', limit: int = 100, offset: int = 0) -> Dict[str, str]:
+        resp = json.loads(self.__request_gate(f'coins?order[{order}]={type_order}&limit={limit}&offset={offset}'))
+        try:
+            return resp["result"]
+        except KeyError:
+            return {}
+
     def get_nft_tokens(self, address: str) -> Dict[str, str]:
         self.__validate_address(address)
         resp = json.loads(self.__request_gate(f'address/{address}/nfts'))
